@@ -11,17 +11,24 @@
 
 #include "storage/data_database_listener.h"
 #include "storage/data_change_notifier.h"
+#include "storage/data_database_state.h"
 #include "utf8stringbuf/utf8stringbuf.h"
 #include <sqlite3.h>
 #include <stdbool.h>
 #include <glib.h>
 
+/*!
+ *  \brief a magic byte sequence by which an Sqlite 3 database file can be recognized
+ */
+extern const char DATA_DATABASE_SQLITE3_MAGIC[16];
+
 /*!
  *  \brief constants of data_database_t
  */
 enum data_database_max_enum {
-    GUI_DATABASE_MAX_FILEPATH = 1024,  /*!< maximum length of filepath */
-    GUI_DATABASE_MAX_LISTENERS = 20,  /*!< maximum listeners. Max 4 Windows and max 3 readers and 2 writers -> 20 is sufficient */
+    DATA_DATABASE_MAX_FILEPATH = 1024,  /*!< maximum length of filepath */
+    DATA_DATABASE_MAX_LISTENERS = 20,  /*!< maximum listeners. Max 3 Windows and max 3 readers and 2 writers */
+                                       /*!< and 1 controller = 16 -> 20 is sufficient */
 };
 
 /*!
@@ -33,11 +40,11 @@ struct data_database_struct {
 
     GMutex private_lock; /*!< lock to ensure that db_file_name, is_open and listener_list are used by only one thread at a time */
     utf8stringbuf_t db_file_name;
-    char private_db_file_name_buffer[GUI_DATABASE_MAX_FILEPATH];
-    bool is_open;
+    char private_db_file_name_buffer[DATA_DATABASE_MAX_FILEPATH];
+    data_database_state_t db_state;
     uint_fast8_t transaction_recursion;  /*!< current transaction depth, 0 if no transaction active */
 
-    data_database_listener_t *(listener_list[GUI_DATABASE_MAX_LISTENERS]);  /*!< array of db-file change listeners. */
+    data_database_listener_t *(listener_list[DATA_DATABASE_MAX_LISTENERS]);  /*!< array of db-file change listeners. */
                                                               /*!< Only in case of a changed db-file, listeners are informed. */
 };
 
@@ -55,6 +62,8 @@ void data_database_init ( data_database_t *this_ );
  *
  *  It is not allowed to open an already opened database.
  *
+ *  Note that this function opens a database writeable or in read-only mode if the file in read-only.
+ *
  *  \param this_ pointer to own object attributes
  *  \param db_file_path a relative or absolute file path
  *  \return U8_ERROR_NO_DB or U8_ERROR_AT_DB if file cannot be opened,
@@ -67,6 +76,8 @@ static inline u8_error_t data_database_open ( data_database_t *this_, const char
  *
  *  Useful for exporting data.
  *
+ *  Note that this function opens even a possibly writeable file in read-only mode.
+ *
  *  \param this_ pointer to own object attributes
  *  \param db_file_path a relative or absolute file path
  *  \return U8_ERROR_NO_DB or U8_ERROR_AT_DB if file cannot be opened,
@@ -166,7 +177,7 @@ u8_error_t data_database_private_initialize_tables( data_database_t *this_ );
 u8_error_t data_database_private_initialize_indexes( data_database_t *this_ );
 
 /*!
- *  \brief upgrades old tables from oder versions to current database scheme
+ *  \brief upgrades old tables from older versions to current database scheme
  *
  *  \param this_ pointer to own object attributes
  *  \return U8_ERROR_AT_DB if the current database is not a database or is encrypted; U8_ERROR_READ_ONLY_DB if read only
@@ -184,7 +195,7 @@ u8_error_t data_database_private_upgrade_tables( data_database_t *this_ );
 u8_error_t data_database_add_db_listener( data_database_t *this_, data_database_listener_t *listener );
 
 /*!
- *  \brief removes a db-file changed listener to the database
+ *  \brief removes a db-file changed listener from the database
  *
  *  \param this_ pointer to own object attributes
  *  \param listener pointer to a listener to be removed
