@@ -8,6 +8,9 @@
 #include <unistd.h>
 #include <assert.h>
 
+const char DATA_DATABASE_SQLITE3_MAGIC[16]
+    = {0x53, 0x51, 0x4c, 0x69, 0x74, 0x65, 0x20, 0x66, 0x6f, 0x72, 0x6d, 0x61, 0x74, 0x20, 0x33, 0x00 };
+
 /*!
  *  \brief string constant to create an sql database table
  *
@@ -431,11 +434,19 @@ void data_database_init ( data_database_t *this_ )
     (*this_).db_file_name = utf8stringbuf_init( sizeof((*this_).private_db_file_name_buffer), (*this_).private_db_file_name_buffer );
     utf8stringbuf_clear( (*this_).db_file_name );
 
-    (*this_).is_open = false;
-    (*this_).transaction_recursion = 0;
-
     g_mutex_init ( &((*this_).private_lock) );
 
+    u8_error_t result = data_database_private_lock( this_ );
+    {
+        (*this_).db_state = DATA_DATABASE_STATE_CLOSED;
+        (*this_).transaction_recursion = 0;
+    }
+    result |= data_database_private_unlock( this_ );
+    if( result != U8_ERROR_NONE )
+    {
+        assert(false);
+    }
+
     data_change_notifier_init ( &((*this_).notifier) );
     data_database_private_clear_db_listener_list( this_ );
 
@@ -454,7 +465,7 @@ u8_error_t data_database_private_open ( data_database_t *this_, const char* db_f
 
     result |= data_database_private_lock( this_ );
 
-    if ( (*this_).is_open )
+    if ( (*this_).db_state != DATA_DATABASE_STATE_CLOSED )
     {
         TRACE_INFO("data_database_open called on database that was not closed.");
         result |= U8_ERROR_INVALID_REQUEST;
@@ -473,7 +484,7 @@ u8_error_t data_database_private_open ( data_database_t *this_, const char* db_f
         {
             TSLOG_ERROR_INT( "sqlite3_open_v2() failed:", sqlite_err );
             TSLOG_ERROR_STR( "sqlite3_open_v2() failed:", utf8stringbuf_get_string( (*this_).db_file_name ) );
-            (*this_).is_open = false;
+            (*this_).db_state = DATA_DATABASE_STATE_CLOSED;
             result |= U8_ERROR_NO_DB;  /* no db to use */
         }
         else
@@ -491,7 +502,10 @@ u8_error_t data_database_private_open ( data_database_t *this_, const char* db_f
 
             if ( init_err == U8_ERROR_NONE )
             {
-                (*this_).is_open = true;
+                (*this_).db_state
+                    = ( (sqlite3_flags & SQLITE_OPEN_MEMORY) == 0 )
+                    ? DATA_DATABASE_STATE_OPEN
+                    : DATA_DATABASE_STATE_IN_MEM;
                 notify_listeners = true;
             }
             else
@@ -503,7 +517,7 @@ u8_error_t data_database_private_open ( data_database_t *this_, const char* db_f
                     TSLOG_ERROR_INT( "sqlite3_close() failed:", sqlite_err );
                 }
                 utf8stringbuf_clear( (*this_).db_file_name );
-                (*this_).is_open = false;
+                (*this_).db_state = DATA_DATABASE_STATE_CLOSED;
             }
             result |= init_err;
         }
@@ -539,7 +553,7 @@ u8_error_t data_database_close ( data_database_t *this_ )
     u8_error_t result = U8_ERROR_NONE;
     bool notify_change_listeners = false;
 
-    if ( (*this_).is_open )
+    if ( (*this_).db_state != DATA_DATABASE_STATE_CLOSED )
     {
         /* prepare close */
         data_change_notifier_emit_signal( &((*this_).notifier),
@@ -556,7 +570,7 @@ u8_error_t data_database_close ( data_database_t *this_ )
 
     result |= data_database_private_lock( this_ );
 
-    if ( (*this_).is_open )
+    if ( (*this_).db_state != DATA_DATABASE_STATE_CLOSED )
     {
         /* perform close */
         TSLOG_EVENT_STR( "sqlite3_close:", utf8stringbuf_get_string( (*this_).db_file_name ) );
@@ -568,7 +582,7 @@ u8_error_t data_database_close ( data_database_t *this_ )
         }
 
         utf8stringbuf_clear( (*this_).db_file_name );
-        (*this_).is_open = false;
+        (*this_).db_state = DATA_DATABASE_STATE_CLOSED;
         (*this_).transaction_recursion = 0;
 
         notify_change_listeners = true;
@@ -604,13 +618,22 @@ void data_database_destroy ( data_database_t *this_ )
     assert( (*this_).transaction_recursion == 0 );
 
     data_database_private_clear_db_listener_list( this_ );
-    if ( (*this_).is_open )
+    if ( (*this_).db_state != DATA_DATABASE_STATE_CLOSED )
     {
         data_database_close( this_ );
     }
     data_change_notifier_destroy( &((*this_).notifier) );
 
-    (*this_).transaction_recursion = 0;
+    u8_error_t result = data_database_private_lock( this_ );
+    {
+        (*this_).transaction_recursion = 0;
+    }
+    result |= data_database_private_unlock( this_ );
+    if( result != U8_ERROR_NONE )
+    {
+        assert(false);
+    }
+
     /* g_mutex_clear ( &((*this_).private_lock) ); -- must not be called because this GMutex is not on the stack */
 
     TRACE_END();
@@ -621,7 +644,7 @@ u8_error_t data_database_flush_caches ( data_database_t *this_ )
     TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
 
-    if ( (*this_).is_open )
+    if ( (*this_).db_state != DATA_DATABASE_STATE_CLOSED )
     {
         TSLOG_EVENT_INT( "sqlite3_libversion_number()", sqlite3_libversion_number() );
         if ( sqlite3_libversion_number() >= 3010000 )
@@ -659,7 +682,7 @@ u8_error_t data_database_trace_stats ( data_database_t *this_ )
     TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
 
-    if ( (*this_).is_open )
+    if ( (*this_).db_state != DATA_DATABASE_STATE_CLOSED )
     {
         sqlite3_int64 use;
         sqlite3_int64 max;
@@ -687,7 +710,7 @@ u8_error_t data_database_add_db_listener( data_database_t *this_, data_database_
     result |= data_database_private_lock( this_ );
 
     int pos = -1;
-    for( int index = 0; index < GUI_DATABASE_MAX_LISTENERS; index ++ )
+    for( int index = 0; index < DATA_DATABASE_MAX_LISTENERS; index ++ )
     {
         if ( NULL == (*this_).listener_list[index] )
         {
@@ -710,7 +733,7 @@ u8_error_t data_database_add_db_listener( data_database_t *this_, data_database_
     }
     else
     {
-        TSLOG_ERROR_INT( "Maximum number of listeners reached.", GUI_DATABASE_MAX_LISTENERS );
+        TSLOG_ERROR_INT( "Maximum number of listeners reached.", DATA_DATABASE_MAX_LISTENERS );
         result |= U8_ERROR_ARRAY_BUFFER_EXCEEDED;
     }
 
@@ -731,7 +754,7 @@ u8_error_t data_database_remove_db_listener( data_database_t *this_, data_databa
 
     result |= data_database_private_lock( this_ );
 
-    for( int index = 0; index < GUI_DATABASE_MAX_LISTENERS; index ++ )
+    for( int index = 0; index < DATA_DATABASE_MAX_LISTENERS; index ++ )
     {
         if ( (*this_).listener_list[index] == listener )
         {
@@ -755,7 +778,7 @@ u8_error_t data_database_remove_db_listener( data_database_t *this_, data_databa
 u8_error_t data_database_private_notify_db_listeners( data_database_t *this_, data_database_listener_signal_t signal_id )
 {
     TRACE_BEGIN();
-    data_database_listener_t *(listener_list_copy[GUI_DATABASE_MAX_LISTENERS]);
+    data_database_listener_t *(listener_list_copy[DATA_DATABASE_MAX_LISTENERS]);
     u8_error_t result = U8_ERROR_NONE;
 
     result |= data_database_private_lock( this_ );
@@ -764,7 +787,7 @@ u8_error_t data_database_private_notify_db_listeners( data_database_t *this_, da
 
     result |= data_database_private_unlock( this_ );
 
-    for( int index = 0; index < GUI_DATABASE_MAX_LISTENERS; index ++ )
+    for( int index = 0; index < DATA_DATABASE_MAX_LISTENERS; index ++ )
     {
         if ( NULL != listener_list_copy[index] )
         {
