@@ -3,8 +3,13 @@
 #include "gui_main_window.h"
 #include "gui_clipboard.h"
 #include "trace/trace.h"
+#include "storage/data_database.h"
 #include "storage/data_change_notifier.h"
 #include "meta/meta_info.h"
+#ifndef NDEBUG
+#include "u8stream/universal_stream_output_stream.h"
+#include "utf8stream/universal_utf8_writer.h"
+#endif  /* not NDEBUG */
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 #include <stdio.h>
@@ -12,7 +17,7 @@
 
 void gui_main_window_init( gui_main_window_t *this_,
                            ctrl_controller_t *controller,
-                           data_database_t *database,
+                           io_data_file_t *data_file,
                            data_database_reader_t *db_reader,
                            gui_resources_t *res,
 #if ( GTK_MAJOR_VERSION >= 4 )
@@ -26,7 +31,10 @@ void gui_main_window_init( gui_main_window_t *this_,
     /* init own attributes */
     (*this_).window_close_observer = window_close_observer;
     (*this_).window_open_observer = window_open_observer;
-    (*this_).database = database;
+    (*this_).data_file = data_file;
+#ifndef NDEBUG
+    (*this_).controller = controller;
+#endif  /* not NDEBUG */
 
     /* init window */
     {
@@ -36,7 +44,7 @@ void gui_main_window_init( gui_main_window_t *this_,
         (*this_).window = gtk_window_new( GTK_WINDOW_TOPLEVEL );
 #endif
         const char *window_title;
-        window_title = data_database_get_filename_ptr( database );
+        window_title = io_data_file_get_filename_ptr( data_file );
         gtk_window_set_title(GTK_WINDOW( (*this_).window ), ( window_title == NULL ) ? META_INFO_PROGRAM_NAME_STR : window_title );
         gtk_widget_set_size_request( (*this_).window, 800, 400 );
         gtk_window_set_default_size( GTK_WINDOW( (*this_).window ), 16*70, 9*70 );
@@ -85,13 +93,13 @@ void gui_main_window_init( gui_main_window_t *this_,
 #endif
     }
 
-    gui_marked_set_init( &((*this_).marker_data) );
+    gui_marked_set_init( &((*this_).marker_data), G_OBJECT((*this_).window) );
     gui_toolbox_init( &((*this_).tools_data),
                       GTK_WIDGET((*this_).tool_row),
-                      GTK_WIDGET((*this_).tool_navigate),
-                      GTK_WIDGET((*this_).tool_edit),
-                      GTK_WIDGET((*this_).tool_create),
-                      GTK_WIDGET((*this_).tool_search),
+                      GTK_WIDGET((*this_).view_navigate),
+                      GTK_WIDGET((*this_).view_edit),
+                      GTK_WIDGET((*this_).view_create),
+                      GTK_WIDGET((*this_).view_search),
                       current_clipboard,
                       &((*this_).marker_data),
                       &((*this_).message_to_user),
@@ -104,7 +112,7 @@ void gui_main_window_init( gui_main_window_t *this_,
     gui_search_runner_init( &((*this_).search_runner),
                             &((*this_).message_to_user),
                             db_reader,
-                            database,
+                            io_data_file_get_database_ptr( data_file ),
                             &((*this_).sketcharea_data)
                           );
     gui_search_request_init( &((*this_).search_request),
@@ -133,23 +141,23 @@ void gui_main_window_init( gui_main_window_t *this_,
                                 GTK_COMBO_BOX( (*this_).type_combo_box ),
                                 GTK_ICON_VIEW( (*this_).type_icon_grid ),
                                 GTK_TEXT_VIEW( (*this_).description_text_view ),
-                                GTK_BUTTON( (*this_).edit_commit_button ),
+                                GTK_BUTTON( (*this_).file_save_button ),
                                 res,
                                 controller,
                                 db_reader,
-                                database,
+                                io_data_file_get_database_ptr( data_file ),
                                 &((*this_).message_to_user)
                               );
 
     /* init the file choosers */
     gui_file_use_db_dialog_init( &((*this_).file_use_db_dialog),
                                  controller,
-                                 database,
+                                 data_file,
                                  GTK_WINDOW( (*this_).window ),
                                  &((*this_).message_to_user)
                                );
     gui_file_export_dialog_init( &((*this_).file_export_dialog),
-                                 database,
+                                 io_data_file_get_database_ptr( data_file ),
                                  db_reader,
                                  GTK_WINDOW( (*this_).window ),
                                  &((*this_).message_to_user)
@@ -214,13 +222,14 @@ void gui_main_window_init( gui_main_window_t *this_,
     g_signal_connect( G_OBJECT((*this_).tool_row), GUI_TOOLBOX_GLIB_SIGNAL_NAME, G_CALLBACK(gui_sketch_area_tool_changed_callback), &((*this_).sketcharea_data) );
     g_signal_connect( G_OBJECT((*this_).file_new_db), "clicked", G_CALLBACK(gui_main_window_new_db_btn_callback), this_ );
     g_signal_connect( G_OBJECT((*this_).file_use_db), "clicked", G_CALLBACK(gui_main_window_open_db_btn_callback), this_ );
+    g_signal_connect( G_OBJECT((*this_).file_save_button), "clicked", G_CALLBACK(gui_main_window_save_btn_callback), this_ );
     g_signal_connect( G_OBJECT((*this_).file_export), "clicked", G_CALLBACK(gui_main_window_export_btn_callback), this_ );
-    g_signal_connect( G_OBJECT((*this_).file_new_window), "clicked", G_CALLBACK(gui_main_window_new_window_btn_callback), this_ );
+    g_signal_connect( G_OBJECT((*this_).view_new_window), "clicked", G_CALLBACK(gui_main_window_new_window_btn_callback), this_ );
 
-    g_signal_connect( G_OBJECT((*this_).tool_navigate), "clicked", G_CALLBACK(gui_toolbox_navigate_btn_callback), &((*this_).tools_data) );
-    g_signal_connect( G_OBJECT((*this_).tool_edit), "clicked", G_CALLBACK(gui_toolbox_edit_btn_callback), &((*this_).tools_data) );
-    g_signal_connect( G_OBJECT((*this_).tool_create), "clicked", G_CALLBACK(gui_toolbox_create_btn_callback), &((*this_).tools_data) );
-    g_signal_connect( G_OBJECT((*this_).tool_search), "clicked", G_CALLBACK(gui_toolbox_search_btn_callback), &((*this_).tools_data) );
+    g_signal_connect( G_OBJECT((*this_).view_navigate), "clicked", G_CALLBACK(gui_toolbox_navigate_btn_callback), &((*this_).tools_data) );
+    g_signal_connect( G_OBJECT((*this_).view_edit), "clicked", G_CALLBACK(gui_toolbox_edit_btn_callback), &((*this_).tools_data) );
+    g_signal_connect( G_OBJECT((*this_).view_create), "clicked", G_CALLBACK(gui_toolbox_create_btn_callback), &((*this_).tools_data) );
+    g_signal_connect( G_OBJECT((*this_).view_search), "clicked", G_CALLBACK(gui_toolbox_search_btn_callback), &((*this_).tools_data) );
 
     g_signal_connect( G_OBJECT((*this_).tool_row), GUI_TOOLBOX_GLIB_SIGNAL_NAME, G_CALLBACK(gui_search_request_tool_changed_callback), &((*this_).search_request) );
     g_signal_connect( G_OBJECT((*this_).search_entry), DATA_CHANGE_NOTIFIER_GLIB_SIGNAL_NAME, G_CALLBACK(gui_search_request_data_changed_callback), &((*this_).search_request) );
@@ -286,8 +295,7 @@ void gui_main_window_init( gui_main_window_t *this_,
     g_signal_connect( G_OBJECT((*this_).stereotype_entry), "activate", G_CALLBACK(gui_attributes_editor_stereotype_enter_callback), &((*this_).attributes_editor) );
     g_signal_connect( G_OBJECT((*this_).type_combo_box), "changed", G_CALLBACK(gui_attributes_editor_type_changed_callback), &((*this_).attributes_editor) );
     g_signal_connect( G_OBJECT((*this_).type_icon_grid), "item-activated", G_CALLBACK(gui_attributes_editor_type_shortlist_callback), &((*this_).attributes_editor) );
-    g_signal_connect( G_OBJECT((*this_).edit_commit_button), "clicked", G_CALLBACK(gui_attributes_editor_commit_clicked_callback), &((*this_).attributes_editor) );
-    g_signal_connect( G_OBJECT((*this_).sketcharea), GUI_SKETCH_AREA_GLIB_SIGNAL_NAME, G_CALLBACK(gui_attributes_editor_selected_object_changed_callback), &((*this_).attributes_editor) );
+    g_signal_connect( G_OBJECT((*this_).window), GUI_MARKED_SET_GLIB_SIGNAL_NAME, G_CALLBACK(gui_attributes_editor_focused_object_changed_callback), &((*this_).attributes_editor) );
     g_signal_connect( G_OBJECT((*this_).name_entry), DATA_CHANGE_NOTIFIER_GLIB_SIGNAL_NAME, G_CALLBACK(gui_attributes_editor_data_changed_callback), &((*this_).attributes_editor) );
         /* ^-- name_entry is the  proxy for all widgets of attributes_editor */
 
@@ -297,7 +305,7 @@ void gui_main_window_init( gui_main_window_t *this_,
 
     /* register observers */
 
-    (*this_).data_notifier = data_database_get_notifier_ptr( database );
+    (*this_).data_notifier = data_database_get_notifier_ptr( io_data_file_get_database_ptr( data_file ) );
     data_change_notifier_add_listener( (*this_).data_notifier, G_OBJECT((*this_).window) );
     data_change_notifier_add_listener( (*this_).data_notifier, G_OBJECT((*this_).sketcharea) );
     data_change_notifier_add_listener( (*this_).data_notifier, G_OBJECT((*this_).name_entry) );
@@ -348,7 +356,10 @@ void gui_main_window_destroy( gui_main_window_t *this_ )
     gui_marked_set_destroy( &((*this_).marker_data) );
     gui_attributes_editor_destroy( &((*this_).attributes_editor) );
     gui_simple_message_to_user_destroy( &((*this_).message_to_user) );
-    (*this_).database = NULL;
+    (*this_).data_file = NULL;
+#ifndef NDEBUG
+    (*this_).controller = NULL;
+#endif  /* not NDEBUG */
 
     TRACE_END();
 }
@@ -377,6 +388,32 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
     gtk_button_set_image( GTK_BUTTON((*this_).file_use_db), (*this_).file_use_db_icon );
     gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).file_use_db), "Open DB" );
 
+    (*this_).file_save_button = gtk_button_new();
+    (*this_).file_save_icon = gtk_image_new_from_pixbuf( gui_resources_get_file_save( res ));
+    gtk_widget_set_size_request( GTK_WIDGET((*this_).file_save_icon), 32 /*=w*/ , 32 /*=h*/ );
+    gtk_button_set_image( GTK_BUTTON((*this_).file_save_button), (*this_).file_save_icon );
+    gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).file_save_button), "Save (Ctrl-S)" );
+#if ( GTK_MAJOR_VERSION >= 4 )
+    GtkShortcutTrigger *commit_trig = gtk_shortcut_trigger_parse_string( "<Control>S" );
+    GtkShortcutAction *commit_act = gtk_callback_action_new( &gui_main_window_save_shortcut_callback,
+                                                             this_,
+                                                             NULL
+                                                           );
+    GtkShortcut* ctrl_s = gtk_shortcut_new_with_arguments( commit_trig,
+                                                           commit_act,
+                                                           NULL /* = format_string */
+                                                         );
+    gtk_shortcut_controller_add_shortcut( (*this_).keyboard_shortcut_ctrl, ctrl_s );
+#else
+    gtk_widget_add_accelerator( GTK_WIDGET((*this_).file_save_button),
+                                "clicked",
+                                (*this_).keyboard_shortcut_group,
+                                GDK_KEY_s,
+                                GDK_CONTROL_MASK,
+                                GTK_ACCEL_VISIBLE
+                              );
+#endif
+
 #if 0
     (*this_).file_save_as_icon = gtk_image_new_from_pixbuf( gui_resources_get_file_save_as( res ));
     gtk_widget_set_size_request( GTK_WIDGET((*this_).file_save_as_icon), 32 /*=w*/ , 32 /*=h*/ );
@@ -407,57 +444,57 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
 #endif
     gtk_widget_set_halign( (*this_).tool_sect_2_icon, GTK_ALIGN_START );
 
-    (*this_).file_new_window_icon = gtk_image_new_from_pixbuf( gui_resources_get_file_new_window( res ));
-    gtk_widget_set_size_request( GTK_WIDGET((*this_).file_new_window_icon), 32 /*=w*/ , 32 /*=h*/ );
-    (*this_).file_new_window = GTK_BUTTON(gtk_button_new());
-    gtk_button_set_image( GTK_BUTTON((*this_).file_new_window), (*this_).file_new_window_icon );
-    gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).file_new_window), "New Window" );
+    (*this_).view_new_window_icon = gtk_image_new_from_pixbuf( gui_resources_get_view_new_window( res ));
+    gtk_widget_set_size_request( GTK_WIDGET((*this_).view_new_window_icon), 32 /*=w*/ , 32 /*=h*/ );
+    (*this_).view_new_window = GTK_BUTTON(gtk_button_new());
+    gtk_button_set_image( GTK_BUTTON((*this_).view_new_window), (*this_).view_new_window_icon );
+    gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).view_new_window), "New Window" );
 
-    (*this_).tool_navigate_icon = gtk_image_new_from_pixbuf( gui_resources_get_tool_navigate( res ));
-    gtk_widget_set_size_request( GTK_WIDGET((*this_).tool_navigate_icon), 32 /*=w*/ , 32 /*=h*/ );
-    (*this_).tool_edit_icon = gtk_image_new_from_pixbuf( gui_resources_get_tool_edit( res ));
-    gtk_widget_set_size_request( GTK_WIDGET((*this_).tool_edit_icon), 32 /*=w*/ , 32 /*=h*/ );
-    (*this_).tool_create_icon = gtk_image_new_from_pixbuf( gui_resources_get_tool_create( res ));
-    gtk_widget_set_size_request( GTK_WIDGET((*this_).tool_create_icon), 32 /*=w*/ , 32 /*=h*/ );
-    (*this_).tool_search_icon = gtk_image_new_from_pixbuf( gui_resources_get_tool_search( res ));
-    gtk_widget_set_size_request( GTK_WIDGET((*this_).tool_search_icon), 32 /*=w*/ , 32 /*=h*/ );
+    (*this_).view_navigate_icon = gtk_image_new_from_pixbuf( gui_resources_get_view_navigate( res ));
+    gtk_widget_set_size_request( GTK_WIDGET((*this_).view_navigate_icon), 32 /*=w*/ , 32 /*=h*/ );
+    (*this_).view_edit_icon = gtk_image_new_from_pixbuf( gui_resources_get_view_edit( res ));
+    gtk_widget_set_size_request( GTK_WIDGET((*this_).view_edit_icon), 32 /*=w*/ , 32 /*=h*/ );
+    (*this_).view_create_icon = gtk_image_new_from_pixbuf( gui_resources_get_view_create( res ));
+    gtk_widget_set_size_request( GTK_WIDGET((*this_).view_create_icon), 32 /*=w*/ , 32 /*=h*/ );
+    (*this_).view_search_icon = gtk_image_new_from_pixbuf( gui_resources_get_view_search( res ));
+    gtk_widget_set_size_request( GTK_WIDGET((*this_).view_search_icon), 32 /*=w*/ , 32 /*=h*/ );
 #if ( GTK_MAJOR_VERSION >= 4 )
-    (*this_).tool_navigate = gtk_toggle_button_new();
-    gtk_button_set_child( GTK_BUTTON((*this_).tool_navigate), (*this_).tool_navigate_icon );
+    (*this_).view_navigate = gtk_toggle_button_new();
+    gtk_button_set_child( GTK_BUTTON((*this_).view_navigate), (*this_).view_navigate_icon );
 
-    (*this_).tool_edit = gtk_toggle_button_new();
-    gtk_button_set_child( GTK_BUTTON((*this_).tool_edit), (*this_).tool_edit_icon );
-    gtk_toggle_button_set_group( GTK_TOGGLE_BUTTON((*this_).tool_edit), GTK_TOGGLE_BUTTON((*this_).tool_navigate) );
+    (*this_).view_edit = gtk_toggle_button_new();
+    gtk_button_set_child( GTK_BUTTON((*this_).view_edit), (*this_).view_edit_icon );
+    gtk_toggle_button_set_group( GTK_TOGGLE_BUTTON((*this_).view_edit), GTK_TOGGLE_BUTTON((*this_).view_navigate) );
 
-    (*this_).tool_create = gtk_toggle_button_new();
-    gtk_button_set_child( GTK_BUTTON((*this_).tool_create), (*this_).tool_create_icon );
-    gtk_toggle_button_set_group( GTK_TOGGLE_BUTTON((*this_).tool_create), GTK_TOGGLE_BUTTON((*this_).tool_edit) );
+    (*this_).view_create = gtk_toggle_button_new();
+    gtk_button_set_child( GTK_BUTTON((*this_).view_create), (*this_).view_create_icon );
+    gtk_toggle_button_set_group( GTK_TOGGLE_BUTTON((*this_).view_create), GTK_TOGGLE_BUTTON((*this_).view_edit) );
 
-    (*this_).tool_search = gtk_toggle_button_new();
-    gtk_button_set_child( GTK_BUTTON((*this_).tool_search), (*this_).tool_search_icon );
-    gtk_toggle_button_set_group( GTK_TOGGLE_BUTTON((*this_).tool_search), GTK_TOGGLE_BUTTON((*this_).tool_create) );
+    (*this_).view_search = gtk_toggle_button_new();
+    gtk_button_set_child( GTK_BUTTON((*this_).view_search), (*this_).view_search_icon );
+    gtk_toggle_button_set_group( GTK_TOGGLE_BUTTON((*this_).view_search), GTK_TOGGLE_BUTTON((*this_).view_create) );
 #else
     GSList *group;
 
-    (*this_).tool_navigate = GTK_WIDGET(gtk_radio_tool_button_new( NULL ));
-    gtk_tool_button_set_icon_widget( GTK_TOOL_BUTTON((*this_).tool_navigate), (*this_).tool_navigate_icon);
-    group = gtk_radio_tool_button_get_group(GTK_RADIO_TOOL_BUTTON ((*this_).tool_navigate));
+    (*this_).view_navigate = GTK_WIDGET(gtk_radio_tool_button_new( NULL ));
+    gtk_tool_button_set_icon_widget( GTK_TOOL_BUTTON((*this_).view_navigate), (*this_).view_navigate_icon);
+    group = gtk_radio_tool_button_get_group(GTK_RADIO_TOOL_BUTTON ((*this_).view_navigate));
 
-    (*this_).tool_edit = GTK_WIDGET(gtk_radio_tool_button_new( group ));
-    gtk_tool_button_set_icon_widget( GTK_TOOL_BUTTON((*this_).tool_edit), (*this_).tool_edit_icon);
-    group = gtk_radio_tool_button_get_group(GTK_RADIO_TOOL_BUTTON ((*this_).tool_edit));
+    (*this_).view_edit = GTK_WIDGET(gtk_radio_tool_button_new( group ));
+    gtk_tool_button_set_icon_widget( GTK_TOOL_BUTTON((*this_).view_edit), (*this_).view_edit_icon);
+    group = gtk_radio_tool_button_get_group(GTK_RADIO_TOOL_BUTTON ((*this_).view_edit));
 
-    (*this_).tool_create = GTK_WIDGET(gtk_radio_tool_button_new( group ));
-    gtk_tool_button_set_icon_widget( GTK_TOOL_BUTTON((*this_).tool_create), (*this_).tool_create_icon);
-    group = gtk_radio_tool_button_get_group(GTK_RADIO_TOOL_BUTTON ((*this_).tool_create));
+    (*this_).view_create = GTK_WIDGET(gtk_radio_tool_button_new( group ));
+    gtk_tool_button_set_icon_widget( GTK_TOOL_BUTTON((*this_).view_create), (*this_).view_create_icon);
+    group = gtk_radio_tool_button_get_group(GTK_RADIO_TOOL_BUTTON ((*this_).view_create));
 
-    (*this_).tool_search = GTK_WIDGET(gtk_radio_tool_button_new( group ));
-    gtk_tool_button_set_icon_widget( GTK_TOOL_BUTTON((*this_).tool_search), (*this_).tool_search_icon);
+    (*this_).view_search = GTK_WIDGET(gtk_radio_tool_button_new( group ));
+    gtk_tool_button_set_icon_widget( GTK_TOOL_BUTTON((*this_).view_search), (*this_).view_search_icon);
 #endif
-    gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).tool_navigate), "Navigate" );
-    gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).tool_edit), "Edit" );
-    gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).tool_create), "Create" );
-    gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).tool_search), "Search" );
+    gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).view_navigate), "Navigate" );
+    gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).view_edit), "Edit" );
+    gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).view_create), "Create" );
+    gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).view_search), "Search" );
 
     (*this_).edit_undo_icon = gtk_image_new_from_pixbuf( gui_resources_get_edit_undo( res ));
     gtk_widget_set_size_request( GTK_WIDGET((*this_).edit_undo_icon), 32 /*=w*/ , 32 /*=h*/ );
@@ -582,14 +619,15 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
 #if ( GTK_MAJOR_VERSION >= 4 )
         gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).file_new_db) );
         gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).file_use_db) );
+        gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).file_save_button) );
         /* gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).file_save_as) ); */
         gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).file_export) );
         gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).tool_sect_1_icon) );
-        gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).file_new_window) );
-        gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).tool_search) );
-        gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).tool_navigate) );
-        gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).tool_edit) );
-        gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).tool_create) );
+        gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).view_new_window) );
+        gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).view_search) );
+        gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).view_navigate) );
+        gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).view_edit) );
+        gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).view_create) );
         gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).tool_sect_2_icon) );
         gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).edit_undo) );
         gtk_box_append( GTK_BOX((*this_).tool_row), GTK_WIDGET((*this_).edit_redo) );
@@ -604,14 +642,15 @@ void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resourc
 #else
         gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).file_new_db) );
         gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).file_use_db) );
+        gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).file_save_button) );
         /* gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).file_save_as) ); */
         gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).file_export) );
         gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).tool_sect_1_icon) );
-        gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).file_new_window) );
-        gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).tool_search) );
-        gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).tool_navigate) );
-        gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).tool_edit) );
-        gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).tool_create) );
+        gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).view_new_window) );
+        gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).view_search) );
+        gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).view_navigate) );
+        gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).view_edit) );
+        gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).view_create) );
         gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).tool_sect_2_icon) );
         gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).edit_undo) );
         gtk_container_add( GTK_CONTAINER((*this_).tool_row), GTK_WIDGET((*this_).edit_redo) );
@@ -685,32 +724,6 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_, g
                                     GTK_POLICY_AUTOMATIC
                                   );
 
-    (*this_).edit_commit_button = gtk_button_new();
-    (*this_).edit_commit_icon = gtk_image_new_from_pixbuf( gui_resources_get_edit_commit( res ));
-    gtk_widget_set_size_request( GTK_WIDGET((*this_).edit_commit_icon), 32 /*=w*/ , 32 /*=h*/ );
-    gtk_button_set_image( GTK_BUTTON((*this_).edit_commit_button), (*this_).edit_commit_icon );
-    gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).edit_commit_button), "Commit (Ctrl-S)" );
-#if ( GTK_MAJOR_VERSION >= 4 )
-    GtkShortcutTrigger *commit_trig = gtk_shortcut_trigger_parse_string( "<Control>S" );
-    GtkShortcutAction *commit_act = gtk_callback_action_new( &gui_attributes_editor_commit_shortcut_callback,
-                                                             &((*this_).attributes_editor),
-                                                             NULL
-                                                           );
-    GtkShortcut* ctrl_s = gtk_shortcut_new_with_arguments( commit_trig,
-                                                           commit_act,
-                                                           NULL /* = format_string */
-                                                         );
-    gtk_shortcut_controller_add_shortcut( (*this_).keyboard_shortcut_ctrl, ctrl_s );
-#else
-    gtk_widget_add_accelerator( GTK_WIDGET((*this_).edit_commit_button),
-                                "clicked",
-                                (*this_).keyboard_shortcut_group,
-                                GDK_KEY_s,
-                                GDK_CONTROL_MASK,
-                                GTK_ACCEL_VISIBLE
-                              );
-#endif
-
     (*this_).type_combo_box = gtk_combo_box_new();
     GtkCellRenderer *column1;
     column1 = gtk_cell_renderer_pixbuf_new();
@@ -758,7 +771,6 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_, g
         gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET(grid_frame) );
         gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET((*this_).description_label) );
         gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET((*this_).description_scroll_win) );
-        gtk_box_append( GTK_BOX((*this_).attr_edit_column), GTK_WIDGET((*this_).edit_commit_button) );
 #else
         gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).attr_section_icon) );
         gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).id_label) );
@@ -771,7 +783,6 @@ void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_, g
         gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).type_icon_grid) );
         gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).description_label) );
         gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).description_scroll_win) );
-        gtk_container_add( GTK_CONTAINER((*this_).attr_edit_column), GTK_WIDGET((*this_).edit_commit_button) );
 #endif
         gtk_widget_set_vexpand( GTK_WIDGET( (*this_).description_scroll_win ), true );
         gtk_widget_set_hexpand( GTK_WIDGET( (*this_).description_scroll_win ), true );
@@ -836,7 +847,7 @@ void gui_main_window_private_init_search_and_sketch_area( gui_main_window_t *thi
         (*this_).search_entry = gtk_entry_new();
 
         (*this_).search_button = gtk_button_new();
-        (*this_).search_btn_icon = gtk_image_new_from_pixbuf( gui_resources_get_tool_search( res ));
+        (*this_).search_btn_icon = gtk_image_new_from_pixbuf( gui_resources_get_view_search( res ));
         gtk_button_set_image( GTK_BUTTON((*this_).search_button), (*this_).search_btn_icon );
         gtk_widget_set_tooltip_text( GTK_WIDGET((*this_).search_button), "Search" );
         gtk_widget_set_size_request( GTK_WIDGET((*this_).search_btn_icon), 32 /*=w*/ , 32 /*=h*/ );
@@ -949,6 +960,67 @@ void gui_main_window_open_db_btn_callback( GtkWidget* button, gpointer data )
     TRACE_END();
 }
 
+void gui_main_window_save_btn_callback( GtkButton *button, gpointer user_data )
+{
+    TRACE_BEGIN();
+    gui_main_window_t *this_;
+    this_ = (gui_main_window_t*) user_data;
+    assert( this_ != NULL );
+
+    gui_simple_message_to_user_hide( &((*this_).message_to_user) );
+
+    gui_attributes_editor_commit_changes ( &((*this_).attributes_editor) );
+
+    u8_error_t d_err;
+    d_err = U8_ERROR_NONE;
+    d_err |= io_data_file_trace_stats( (*this_).data_file );
+    d_err |= io_data_file_sync_to_disk( (*this_).data_file );
+    d_err |= io_data_file_trace_stats( (*this_).data_file );
+    if ( U8_ERROR_NONE != d_err )
+    {
+        gui_simple_message_to_user_show_message( &((*this_).message_to_user),
+                                                 GUI_SIMPLE_MESSAGE_TYPE_WARNING,
+                                                 GUI_SIMPLE_MESSAGE_CONTENT_DB_FILE_WRITE_ERROR
+        );
+    }
+    else
+    {
+#ifndef NDEBUG
+        /* in debug mode, also check consistency of database */
+        universal_stream_output_stream_t out_stream;
+        universal_stream_output_stream_init( &out_stream, stdout );
+        universal_output_stream_t *const out_base = universal_stream_output_stream_get_output_stream( &out_stream );
+        universal_utf8_writer_t out_report;
+        universal_utf8_writer_init( &out_report, out_base );
+        uint32_t found_errors;
+        uint32_t fixed_errors;
+        ctrl_controller_repair_database( (*this_).controller, false /* no repair, just test */, &found_errors, &fixed_errors, &out_report );
+        if (( found_errors != 0 ) || ( fixed_errors != 0 ))
+        {
+            gui_simple_message_to_user_show_message_with_quantity( &((*this_).message_to_user),
+                                                                   GUI_SIMPLE_MESSAGE_TYPE_ERROR,
+                                                                   GUI_SIMPLE_MESSAGE_CONTENT_DB_INCONSISTENT,
+                                                                   found_errors
+                                                                 );
+        }
+        universal_utf8_writer_destroy( &out_report );
+        universal_stream_output_stream_destroy( &out_stream );
+#endif
+    }
+
+    TRACE_TIMESTAMP();
+    TRACE_END();
+}
+
+#if ( GTK_MAJOR_VERSION >= 4 )
+gboolean gui_main_window_save_shortcut_callback( GtkWidget* widget, GVariant* args, gpointer user_data )
+{
+    gui_main_window_save_btn_callback( (GtkButton*)widget, user_data );
+    return TRUE;
+}
+#else
+#endif
+
 void gui_main_window_export_btn_callback( GtkWidget* button, gpointer data )
 {
     TRACE_BEGIN();
@@ -1008,7 +1080,7 @@ void gui_main_window_data_changed_callback( GtkWidget *window, data_change_messa
         || ( DATA_CHANGE_EVENT_TYPE_DB_CLOSED == data_change_message_get_event( msg ) ))
     {
         /* the database has changed */
-        const char *filename = data_database_get_filename_ptr( (*this_).database );
+        const char *filename = io_data_file_get_filename_ptr( (*this_).data_file );
         if ( NULL == filename )
         {
             gtk_window_set_title(GTK_WINDOW((*this_).window), META_INFO_PROGRAM_NAME_STR );
