@@ -14,7 +14,7 @@
 
 #include "resources/crystal_facet_uml.c"
 #include "resources/edit_attributes_sect.c"
-#include "resources/edit_commit.c"
+#include "resources/file_save.c"
 #include "resources/edit_copy.c"
 #include "resources/edit_cut.c"
 #include "resources/edit_delete.c"
@@ -26,17 +26,17 @@
 #include "resources/edit_reset.c"
 #include "resources/file_export.c"
 #include "resources/file_new_db.c"
-#include "resources/file_new_window.c"
+#include "resources/view_new_window.c"
 #include "resources/file_save_as.c"
 #include "resources/file_use_db.c"
 #include "resources/message_error.c"
 #include "resources/message_info.c"
 #include "resources/message_warn.c"
 #include "resources/message_user_doc.c"
-#include "resources/tool_search.c"
-#include "resources/tool_navigate.c"
-#include "resources/tool_create.c"
-#include "resources/tool_edit.c"
+#include "resources/view_search.c"
+#include "resources/view_navigate.c"
+#include "resources/view_create.c"
+#include "resources/view_edit.c"
 #include "resources/tool_sect.c"
 #include "resources/navigate_breadcrumb_folder.c"
 #include "resources/navigate_closed_folder.c"
@@ -139,7 +139,7 @@ void gui_resources_init ( gui_resources_t *this_ )
 
     (*this_).edit_attributes_sect = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( edit_attributes_sect ) );
 
-    (*this_).edit_commit = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( edit_commit ) );
+    (*this_).file_save = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( file_save ) );
     (*this_).edit_copy = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( edit_copy ) );
     (*this_).edit_cut = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( edit_cut ) );
     (*this_).edit_delete = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( edit_delete ) );
@@ -152,7 +152,7 @@ void gui_resources_init ( gui_resources_t *this_ )
 
     (*this_).file_export = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( file_export ) );
     (*this_).file_new_db = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( file_new_db ) );
-    (*this_).file_new_window = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( file_new_window ) );
+    (*this_).view_new_window = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( view_new_window ) );
     (*this_).file_save_as = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( file_save_as ) );
     (*this_).file_use_db = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( file_use_db ) );
 
@@ -162,10 +162,10 @@ void gui_resources_init ( gui_resources_t *this_ )
 
     (*this_).message_user_doc = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( message_user_doc ) );
 
-    (*this_).tool_search = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( tool_search ) );
-    (*this_).tool_navigate = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( tool_navigate ) );
-    (*this_).tool_create = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( tool_create ) );
-    (*this_).tool_edit = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( tool_edit ) );
+    (*this_).view_search = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( view_search ) );
+    (*this_).view_navigate = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( view_navigate ) );
+    (*this_).view_create = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( view_create ) );
+    (*this_).view_edit = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( view_edit ) );
     (*this_).tool_sect = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( tool_sect ) );
 
     (*this_).navigate_breadcrumb_folder = gdk_pixbuf_new_from_data( GIMP_PIXBUF_DATA( navigate_breadcrumb_folder ) );
@@ -269,7 +269,7 @@ void gui_resources_destroy ( gui_resources_t *this_ )
 
     g_object_unref ((*this_).edit_attributes_sect);
 
-    g_object_unref ((*this_).edit_commit);
+    g_object_unref ((*this_).file_save);
     g_object_unref ((*this_).edit_copy);
     g_object_unref ((*this_).edit_cut);
     g_object_unref ((*this_).edit_delete);
@@ -282,7 +282,7 @@ void gui_resources_destroy ( gui_resources_t *this_ )
 
     g_object_unref ((*this_).file_export);
     g_object_unref ((*this_).file_new_db);
-    g_object_unref ((*this_).file_new_window);
+    g_object_unref ((*this_).view_new_window);
     g_object_unref ((*this_).file_save_as);
     g_object_unref ((*this_).file_use_db);
 
@@ -292,10 +292,10 @@ void gui_resources_destroy ( gui_resources_t *this_ )
 
     g_object_unref ((*this_).message_user_doc);
 
-    g_object_unref ((*this_).tool_search);
-    g_object_unref ((*this_).tool_navigate);
-    g_object_unref ((*this_).tool_create);
-    g_object_unref ((*this_).tool_edit);
+    g_object_unref ((*this_).view_search);
+    g_object_unref ((*this_).view_navigate);
+    g_object_unref ((*this_).view_create);
+    g_object_unref ((*this_).view_edit);
     g_object_unref ((*this_).tool_sect);
 
     g_object_unref ((*this_).navigate_breadcrumb_folder);
