@@ -62,8 +62,9 @@ void gui_simple_message_to_user_show_message ( gui_simple_message_to_user_t *thi
                                     );
             utf8stringbuf_append_str( (*this_).private_temp_str,
                                         "\n"
+                                        "License: " META_INFO_LICENSE_STR "\n"
                                         "Copyright: " META_INFO_COPYRIGHT_STR "\n"
-                                        "License: " META_INFO_LICENSE_STR
+                                        "Thanks to all who have contributed to improving and deploying this tool."
                                     );
         }
         break;
@@ -304,6 +305,18 @@ void gui_simple_message_to_user_show_message_with_name ( gui_simple_message_to_u
         utf8stringbuf_append_str( (*this_).private_temp_str, "Name already in use (use copy and paste to insert the existing object): " );
         utf8stringbuf_append_str( (*this_).private_temp_str, name );
     }
+    else if ( content_id == GUI_SIMPLE_MESSAGE_CONTENT_LOADING_WAIT )
+    {
+        TSLOG_EVENT( "GUI_SIMPLE_MESSAGE_CONTENT_LOADING_WAIT" );
+        utf8stringbuf_append_str( (*this_).private_temp_str, "Loading DB file ...\n" );
+        utf8stringbuf_append_str( (*this_).private_temp_str, name );
+    }
+    else if ( content_id == GUI_SIMPLE_MESSAGE_CONTENT_EXPORTING_WAIT )
+    {
+        TSLOG_EVENT( "GUI_SIMPLE_MESSAGE_CONTENT_EXPORTING_WAIT" );
+        utf8stringbuf_append_str( (*this_).private_temp_str, "Exporting files ...\n" );
+        utf8stringbuf_append_str( (*this_).private_temp_str, name );
+    }
     else
     {
         TSLOG_ERROR("unexptected content_id");
