@@ -1,9 +1,9 @@
 /* File: xhtml_stylesheet_writer.c; Copyright and License: see below */
 
 #include "xhtml/xhtml_stylesheet_writer.h"
-#include "util/string/utf8string.h"
-#include "trace.h"
-#include "tslog.h"
+#include "utf8stringbuf/utf8string.h"
+#include "trace/trace.h"
+#include "tslog/tslog.h"
 #include <stdbool.h>
 #include <assert.h>
 
