@@ -5,14 +5,14 @@
 #include "xmi/xmi_element_info.h"
 #include "xmi/xmi_element_part.h"
 #include "xmi/xmi_xml.h"
-#include "util/string/utf8string.h"
-#include "util/string/utf8stringview.h"
-#include "util/string/utf8stringviewiterator.h"
+#include "utf8stringbuf/utf8string.h"
+#include "utf8stringbuf/utf8stringview.h"
+#include "utf8stringbuf/utf8stringviewiterator.h"
 #include "data_id.h"
 #include "meta/meta_version.h"
 #include "meta/meta_info.h"
-#include "trace.h"
-#include "tslog.h"
+#include "trace/trace.h"
+#include "tslog/tslog.h"
 #include <stdio.h>
 #include <stdbool.h>
 #include <assert.h>
