@@ -5,11 +5,11 @@
 #include "xmi/xmi_element_info.h"
 #include "xmi/xmi_element_part.h"
 #include "xmi/xmi_xml.h"
-#include "util/string/utf8string.h"
+#include "utf8stringbuf/utf8string.h"
 #include "data_id.h"
 #include "data_classifier_type.h"
-#include "trace.h"
-#include "tslog.h"
+#include "trace/trace.h"
+#include "tslog/tslog.h"
 #include <stdio.h>
 #include <stdbool.h>
 #include <assert.h>
