@@ -13,6 +13,8 @@
 #define META_INFO_PROGRAM_NAME_STR "crystal facet uml"
 /* machine readable version */
 #define META_INFO_PROGRAM_ID_STR "crystal-facet-uml"
+/* X-Desktop ID */
+#define META_INFO_APPLICATION_ID_STR "crystal-facet-uml.desktop"
 #define META_INFO_COPYRIGHT_STR /*Copyright*/ "2016-2022 Andreas Warnke"
 #ifdef __linux__
 #define META_INFO_LICENSE_STR "Apache-2.0"  /* sqlite3 linked dynamicyally */
@@ -24,7 +26,7 @@
 
 
 /*
-Copyright 2016-2021 Andreas Warnke
+Copyright 2016-2022 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
