@@ -15,7 +15,7 @@
 /*!
  *  \brief main starts the gui (or a headless feature)
  */
-int main (int argc, char *argv[]);
+int main (int argc, char **argv);
 
 /*!
  *  \brief compares the command line options to the available export file formats
@@ -35,7 +35,7 @@ io_import_mode_t main_private_get_selected_mode( char *arg_fmt );
 
 
 /*
-Copyright 2019-2021 Andreas Warnke
+Copyright 2019-2022 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
