@@ -13,9 +13,9 @@
 #include "pencil_size.h"
 #include "pencil_layout_data.h"
 #include "pencil_feature_layouter.h"
-#include "util/geometry/geometry_rectangle.h"
-#include "util/geometry/geometry_dimensions.h"
-#include "util/geometry/geometry_non_linear_scale.h"
+#include "geometry/geometry_rectangle.h"
+#include "geometry/geometry_dimensions.h"
+#include "geometry/geometry_non_linear_scale.h"
 #include "data_diagram.h"
 #include "set/data_small_set.h"
 #include "data_id.h"
