@@ -17,10 +17,10 @@
 #include "draw/draw_classifier_icon.h"
 #include "draw/draw_classifier_label.h"
 #include "draw/draw_classifier_contour.h"
-#include "util/geometry/geometry_rectangle.h"
-#include "util/geometry/geometry_dimensions.h"
-#include "util/geometry/geometry_h_align.h"
-#include "util/geometry/geometry_v_align.h"
+#include "geometry/geometry_rectangle.h"
+#include "geometry/geometry_dimensions.h"
+#include "geometry/geometry_h_align.h"
+#include "geometry/geometry_v_align.h"
 #include "data_diagram.h"
 #include "set/data_small_set.h"
 #include "data_id.h"
