@@ -12,9 +12,9 @@
 #include "pencil_size.h"
 #include "pencil_layout_data.h"
 #include "pencil_feature_painter.h"
-#include "util/geometry/geometry_rectangle.h"
-#include "util/geometry/geometry_dimensions.h"
-#include "util/geometry/geometry_non_linear_scale.h"
+#include "geometry/geometry_rectangle.h"
+#include "geometry/geometry_dimensions.h"
+#include "geometry/geometry_non_linear_scale.h"
 #include "data_diagram.h"
 #include "set/data_visible_set.h"
 #include "set/data_small_set.h"
