@@ -13,8 +13,8 @@
 #include "pencil_size.h"
 #include "layout/layout_feature.h"
 #include "draw/draw_feature_label.h"
-#include "util/geometry/geometry_rectangle.h"
-#include "util/geometry/geometry_dimensions.h"
+#include "geometry/geometry_rectangle.h"
+#include "geometry/geometry_dimensions.h"
 #include "data_diagram.h"
 #include "set/data_small_set.h"
 #include "data_id.h"
