@@ -10,9 +10,9 @@
  */
 
 #include "pencil_layout_data.h"
-#include "util/geometry/geometry_rectangle.h"
-#include "util/geometry/geometry_point.h"
-/* #include "util/geometry/geometry_anchor.h" */
+#include "geometry/geometry_rectangle.h"
+#include "geometry/geometry_point.h"
+/* #include "geometry/geometry_anchor.h" */
 
 /*!
  *  \brief attributes of the label layout helper
