@@ -42,10 +42,14 @@ void pencil_layouter_init( pencil_layouter_t *this_, const data_visible_set_t *i
                                         &((*this_).layout_data),
                                         &((*this_).pencil_size)
                                       );
-    pencil_relationship_layouter_init( &((*this_).pencil_relationship_layouter),
+    pencil_relationship_2d_layouter_init( &((*this_).pencil_relationship_2d_layouter),
                                        &((*this_).layout_data),
                                        &((*this_).pencil_size)
                                      );
+    pencil_relationship_1d_layouter_init( &((*this_).pencil_relationship_1d_layouter),
+                                          &((*this_).layout_data),
+                                          &((*this_).pencil_size)
+                                        );
     pencil_rel_label_layouter_init( &((*this_).relationship_label_layouter),
                                     &((*this_).layout_data),
                                     &((*this_).pencil_size)
@@ -69,7 +73,8 @@ void pencil_layouter_destroy( pencil_layouter_t *this_ )
     TRACE_BEGIN();
 
     pencil_rel_label_layouter_destroy( &((*this_).relationship_label_layouter) );
-    pencil_relationship_layouter_destroy( &((*this_).pencil_relationship_layouter) );
+    pencil_relationship_1d_layouter_destroy( &((*this_).pencil_relationship_1d_layouter) );
+    pencil_relationship_2d_layouter_destroy( &((*this_).pencil_relationship_2d_layouter) );
     pencil_classifier_1d_layouter_destroy( &((*this_).pencil_classifier_1d_layouter) );
     pencil_classifier_2d_layouter_destroy( &((*this_).pencil_classifier_2d_layouter) );
     pencil_feat_label_layouter_destroy( &((*this_).feature_label_layouter) );
@@ -176,7 +181,7 @@ void pencil_layouter_layout_elements ( pencil_layouter_t *this_, PangoLayout *fo
         pencil_feature_layouter_do_layout( &((*this_).feature_layouter), font_layout );
 
         /* hide relationships in simple list and box diagrams */
-        pencil_relationship_layouter_layout_void( &((*this_).pencil_relationship_layouter) );
+        pencil_relationship_2d_layouter_layout_void( &((*this_).pencil_relationship_2d_layouter) );
 
         /* layout labels of features */
         pencil_feat_label_layouter_do_layout( &((*this_).feature_label_layouter), font_layout );
@@ -190,7 +195,7 @@ void pencil_layouter_layout_elements ( pencil_layouter_t *this_, PangoLayout *fo
         pencil_feature_layouter_do_layout( &((*this_).feature_layouter), font_layout );
 
         /* calculate the relationship shapes for a sequence diagram */
-        pencil_relationship_layouter_layout_for_sequence( &((*this_).pencil_relationship_layouter) );
+        pencil_relationship_1d_layouter_layout_for_sequence( &((*this_).pencil_relationship_1d_layouter) );
 
         /* layout labels of relationships */
         pencil_rel_label_layouter_do_layout( &((*this_).relationship_label_layouter), font_layout );
@@ -204,7 +209,7 @@ void pencil_layouter_layout_elements ( pencil_layouter_t *this_, PangoLayout *fo
         pencil_feature_layouter_do_layout( &((*this_).feature_layouter), font_layout );
 
         /* calculate the relationship shapes for a timing diagram */
-        pencil_relationship_layouter_layout_for_timing( &((*this_).pencil_relationship_layouter) );
+        pencil_relationship_1d_layouter_layout_for_timing( &((*this_).pencil_relationship_1d_layouter) );
 
         /* layout labels of relationships */
         pencil_rel_label_layouter_do_layout( &((*this_).relationship_label_layouter), font_layout );
@@ -229,17 +234,17 @@ void pencil_layouter_layout_elements ( pencil_layouter_t *this_, PangoLayout *fo
         if ( DATA_DIAGRAM_TYPE_BOX_DIAGRAM == diag_type )
         {
             /* hide relationships in simple list and box diagrams */
-            pencil_relationship_layouter_layout_void( &((*this_).pencil_relationship_layouter) );
+            pencil_relationship_2d_layouter_layout_void( &((*this_).pencil_relationship_2d_layouter) );
         }
         else if (( DATA_DIAGRAM_TYPE_UML_COMMUNICATION_DIAGRAM == diag_type )||( DATA_DIAGRAM_TYPE_INTERACTION_OVERVIEW_DIAGRAM == diag_type ))
         {
             /* calculate the relationship shapes for a communication diagram or an interaction overview diagram (scenario-relations only) */
-            pencil_relationship_layouter_layout_for_communication( &((*this_).pencil_relationship_layouter) );
+            pencil_relationship_2d_layouter_layout_for_communication( &((*this_).pencil_relationship_2d_layouter) );
         }
         else
         {
             /* calculate the relationship shapes */
-            pencil_relationship_layouter_layout_standard( &((*this_).pencil_relationship_layouter) );
+            pencil_relationship_2d_layouter_layout_standard( &((*this_).pencil_relationship_2d_layouter) );
         }
 
         /* hide containment relationships if children are embraced */
@@ -248,7 +253,6 @@ void pencil_layouter_layout_elements ( pencil_layouter_t *this_, PangoLayout *fo
         /* layout labels of features and relationships */
         pencil_feat_label_layouter_do_layout( &((*this_).feature_label_layouter), font_layout );
         pencil_rel_label_layouter_do_layout( &((*this_).relationship_label_layouter), font_layout );
-
     }
 
     if ( io_layout_stat != NULL )
@@ -337,16 +341,16 @@ pencil_error_t pencil_layouter_get_object_id_at_pos ( const pencil_layouter_t *t
                                                       double y,
                                                       double snap_distance,
                                                       pencil_type_filter_t filter,
-                                                      data_id_pair_t* out_selected_id,
-                                                      data_id_pair_t* out_surrounding_id )
+                                                      data_full_id_t* out_selected_id,
+                                                      data_full_id_t* out_surrounding_id )
 {
     TRACE_BEGIN();
     assert( NULL != out_selected_id );
     assert( NULL != out_surrounding_id );
 
     pencil_error_t result = PENCIL_ERROR_NONE;
-    data_id_pair_reinit_void( out_selected_id );
-    data_id_pair_reinit_void( out_surrounding_id );
+    data_full_id_reinit_void( out_selected_id );
+    data_full_id_reinit_void( out_surrounding_id );
     const layout_diagram_t *the_diagram;
     the_diagram = pencil_layout_data_get_diagram_const( &((*this_).layout_data) );
     const data_diagram_t *diagram_data;
@@ -369,7 +373,7 @@ pencil_error_t pencil_layouter_get_object_id_at_pos ( const pencil_layouter_t *t
         }
 
         /* determine a feature at the given position */
-        if ( ! data_id_pair_is_valid( out_selected_id ) )
+        if ( ! data_full_id_is_valid( out_selected_id ) )
         {
             result = pencil_layouter_private_get_feature_id_at_pos( this_,
                                                                     x,
@@ -381,7 +385,7 @@ pencil_error_t pencil_layouter_get_object_id_at_pos ( const pencil_layouter_t *t
         }
 
         /* determine a classifier at the given position */
-        if ( ! data_id_pair_is_valid( out_selected_id ) )
+        if ( ! data_full_id_is_valid( out_selected_id ) )
         {
             result = pencil_layouter_private_get_classifier_id_at_pos( this_,
                                                                        x,
@@ -392,18 +396,18 @@ pencil_error_t pencil_layouter_get_object_id_at_pos ( const pencil_layouter_t *t
         }
 
         /* fallback: return the diagram */
-        if ( ! data_id_pair_is_valid( out_selected_id ) )
+        if ( ! data_full_id_is_valid( out_selected_id ) )
         {
-            data_id_pair_reinit_by_table_and_id ( out_selected_id,
+            data_full_id_reinit_by_table_and_id ( out_selected_id,
                                                   DATA_TABLE_DIAGRAM,
                                                   data_diagram_get_row_id(diagram_data),
                                                   DATA_TABLE_VOID,
                                                   DATA_ROW_ID_VOID
                                                 );
         }
-        if ( ! data_id_pair_is_valid( out_surrounding_id ) )
+        if ( ! data_full_id_is_valid( out_surrounding_id ) )
         {
-            data_id_pair_reinit_by_table_and_id ( out_surrounding_id,
+            data_full_id_reinit_by_table_and_id ( out_surrounding_id,
                                                   DATA_TABLE_DIAGRAM,
                                                   data_diagram_get_row_id(diagram_data),
                                                   DATA_TABLE_VOID,
@@ -424,8 +428,8 @@ pencil_error_t pencil_layouter_get_object_id_at_pos ( const pencil_layouter_t *t
 pencil_error_t pencil_layouter_private_get_classifier_id_at_pos ( const pencil_layouter_t *this_,
                                                                   double x,
                                                                   double y,
-                                                                  data_id_pair_t* out_selected_id,
-                                                                  data_id_pair_t* out_surrounding_id )
+                                                                  data_full_id_t* out_selected_id,
+                                                                  data_full_id_t* out_surrounding_id )
 {
     TRACE_BEGIN();
     assert( NULL != out_selected_id );
@@ -464,7 +468,7 @@ pencil_error_t pencil_layouter_private_get_classifier_id_at_pos ( const pencil_l
                     if ( current_classifier_area < surrounding_classifier_area )
                     {
                         surrounding_classifier_area = current_classifier_area;
-                        data_id_pair_reinit_by_table_and_id ( out_surrounding_id,
+                        data_full_id_reinit_by_table_and_id ( out_surrounding_id,
                                                               DATA_TABLE_DIAGRAMELEMENT,
                                                               layout_visible_classifier_get_diagramelement_id( visible_classifier ),
                                                               DATA_TABLE_CLASSIFIER,
@@ -475,7 +479,7 @@ pencil_error_t pencil_layouter_private_get_classifier_id_at_pos ( const pencil_l
                 else
                 {
                     /* classifier is found */
-                    data_id_pair_reinit_by_table_and_id ( out_selected_id,
+                    data_full_id_reinit_by_table_and_id ( out_selected_id,
                                                           DATA_TABLE_DIAGRAMELEMENT,
                                                           layout_visible_classifier_get_diagramelement_id( visible_classifier ),
                                                           DATA_TABLE_CLASSIFIER,
@@ -496,8 +500,8 @@ pencil_error_t pencil_layouter_private_get_feature_id_at_pos ( const pencil_layo
                                                                double x,
                                                                double y,
                                                                pencil_type_filter_t filter,
-                                                               data_id_pair_t* out_selected_id,
-                                                               data_id_pair_t* out_surrounding_id )
+                                                               data_full_id_t* out_selected_id,
+                                                               data_full_id_t* out_surrounding_id )
 {
     TRACE_BEGIN();
     assert( NULL != out_selected_id );
@@ -524,7 +528,7 @@ pencil_error_t pencil_layouter_private_get_feature_id_at_pos ( const pencil_layo
             if (( PENCIL_TYPE_FILTER_LIFELINE == filter )
                 &&( DATA_FEATURE_TYPE_LIFELINE == data_feature_get_main_type( data_feature ) ))
             {
-                data_id_pair_reinit_by_table_and_id ( out_selected_id,
+                data_full_id_reinit_by_table_and_id ( out_selected_id,
                                                       DATA_TABLE_DIAGRAMELEMENT,
                                                       layout_visible_classifier_get_diagramelement_id( layout_classifier ),
                                                       DATA_TABLE_CLASSIFIER,
@@ -533,7 +537,7 @@ pencil_error_t pencil_layouter_private_get_feature_id_at_pos ( const pencil_layo
             }
             else
             {
-                data_id_pair_reinit_by_table_and_id ( out_selected_id,
+                data_full_id_reinit_by_table_and_id ( out_selected_id,
                                                       DATA_TABLE_FEATURE,
                                                       layout_feature_get_feature_id( the_feature ),
                                                       DATA_TABLE_CLASSIFIER,
@@ -541,7 +545,7 @@ pencil_error_t pencil_layouter_private_get_feature_id_at_pos ( const pencil_layo
                                                     );
             }
 
-            data_id_pair_reinit_by_table_and_id ( out_surrounding_id,
+            data_full_id_reinit_by_table_and_id ( out_surrounding_id,
                                                   DATA_TABLE_DIAGRAMELEMENT,
                                                   layout_visible_classifier_get_diagramelement_id( layout_classifier ),
                                                   DATA_TABLE_CLASSIFIER,
@@ -560,7 +564,7 @@ pencil_error_t pencil_layouter_private_get_relationship_id_at_pos ( const pencil
                                                                     double x,
                                                                     double y,
                                                                     double snap_distance,
-                                                                    data_id_pair_t* out_selected_id )
+                                                                    data_full_id_t* out_selected_id )
 {
     TRACE_BEGIN();
     assert( NULL != out_selected_id );
@@ -587,7 +591,7 @@ pencil_error_t pencil_layouter_private_get_relationship_id_at_pos ( const pencil
                 const data_relationship_t *relation_data;
                 relation_data = layout_relationship_get_data_const( current_relation );
 
-                data_id_pair_reinit_by_table_and_id ( out_selected_id,
+                data_full_id_reinit_by_table_and_id ( out_selected_id,
                                                       DATA_TABLE_RELATIONSHIP,
                                                       data_relationship_get_row_id( relation_data ),
                                                       DATA_TABLE_VOID,
