@@ -6,12 +6,12 @@
 #include "test_data/test_data_setup.h"
 #include "trace/trace.h"
 #include "test_assert.h"
-        
+
 static void set_up(void);
 static void tear_down(void);
 static void layout_good_cases(void);
 static void layout_challenging_cases(void);
-#ifndef NDEBUG                
+#ifndef NDEBUG
 static void layout_edge_cases(void);
 #endif
 
@@ -21,7 +21,7 @@ test_suite_t pencil_diagram_maker_test_get_suite(void)
     test_suite_init( &result, "pencil_diagram_maker_test_get_suite", &set_up, &tear_down );
     test_suite_add_test_case( &result, "layout_good_cases", &layout_good_cases );
     test_suite_add_test_case( &result, "layout_challenging_cases", &layout_challenging_cases );
-#ifndef NDEBUG                
+#ifndef NDEBUG
     test_suite_add_test_case( &result, "layout_edge_cases", &layout_edge_cases );
 #endif
     return result;
@@ -33,7 +33,7 @@ static cairo_surface_t *surface;
 static cairo_t *cr;
 static geometry_rectangle_t diagram_bounds;
 
-#ifndef NDEBUG                
+#ifndef NDEBUG
 #define PENCIL_DIAGRAM_MAKER_TEST_EXPORT_SAMPLES
 #else
 #endif
@@ -43,7 +43,7 @@ static void set_up(void)
     data_visible_set_init( &data_set );
     pencil_diagram_maker_init( &painter, &data_set );
     geometry_rectangle_init( &diagram_bounds, 0.0, 0.0, 640.0, 480.0 );
-    surface = cairo_image_surface_create( CAIRO_FORMAT_ARGB32, 
+    surface = cairo_image_surface_create( CAIRO_FORMAT_ARGB32,
                                           (uint32_t) geometry_rectangle_get_width( &diagram_bounds ),
                                           (uint32_t) geometry_rectangle_get_height( &diagram_bounds )
                                         );
@@ -61,7 +61,7 @@ static void tear_down(void)
     pencil_diagram_maker_destroy( &painter );
     data_visible_set_destroy( &data_set );
 }
- 
+
 static void draw_background()
 {
     /* draw paper */
@@ -82,39 +82,39 @@ static void render_to_file( const test_data_setup_t *ts_case_setup, data_stat_t
     char filename_buf[48]="";
     utf8stringbuf_t filename = UTF8STRINGBUF(filename_buf);
     utf8stringbuf_append_str( filename, "test_pencil" );
-    
+
     const unsigned int variant = test_data_setup_get_variant( ts_case_setup );
     switch ( test_data_setup_get_mode( ts_case_setup ) )
     {
         default:
         case TEST_DATA_SETUP_MODE_GOOD_CASES:
         {
-            utf8stringbuf_append_str( filename, "_g_" );
+            utf8stringbuf_append_str( filename, "_good" );
         }
         break;
 
         case TEST_DATA_SETUP_MODE_CHALLENGING_CASES:
         {
-            utf8stringbuf_append_str( filename, "_c_" );
+            utf8stringbuf_append_str( filename, "_cllg" );
         }
         break;
 
         case TEST_DATA_SETUP_MODE_EDGE_CASES:
         {
-            utf8stringbuf_append_str( filename, "_e_" );
+            utf8stringbuf_append_str( filename, "_edge" );
         }
         break;
     }
-    utf8stringbuf_append_str( filename, "E=" );
-    utf8stringbuf_append_int( filename, data_stat_get_series_count( render_stats, DATA_STAT_SERIES_ERROR ) );
-    utf8stringbuf_append_str( filename, "-W=" );
-    utf8stringbuf_append_int( filename, data_stat_get_series_count( render_stats, DATA_STAT_SERIES_WARNING ) );
-    utf8stringbuf_append_str( filename, "-Ok=" );
-    utf8stringbuf_append_int( filename, data_stat_get_series_count( render_stats, DATA_STAT_SERIES_EXPORTED ) );
     utf8stringbuf_append_str( filename, "_" );
+    utf8stringbuf_append_int( filename, data_stat_get_series_count( render_stats, DATA_STAT_SERIES_ERROR ) );
+    utf8stringbuf_append_str( filename, "e_" );
+    utf8stringbuf_append_int( filename, data_stat_get_series_count( render_stats, DATA_STAT_SERIES_WARNING ) );
+    utf8stringbuf_append_str( filename, "w_" );
+    utf8stringbuf_append_int( filename, data_stat_get_series_count( render_stats, DATA_STAT_SERIES_EXPORTED ) );
+    utf8stringbuf_append_str( filename, "ok_" );
     utf8stringbuf_append_int( filename, variant );
     utf8stringbuf_append_str( filename, ".png" );
-    
+
     /* finish surface */
     const cairo_status_t png_result
         = cairo_surface_write_to_png ( surface, utf8stringbuf_get_string( filename ) );
@@ -147,7 +147,7 @@ static void layout_good_cases(void)
                                     &void_set,
                                     cr
                                   );
-        
+
         /* check result */
         /* TODO, manual check for now */
 #ifdef PENCIL_DIAGRAM_MAKER_TEST_EXPORT_SAMPLES
@@ -167,7 +167,7 @@ static void layout_challenging_cases(void)
         /* setup */
         test_data_setup_get_variant_data( &ts_setup, &data_set );
         draw_background();
-        
+
         /* perform test: draw diagram */
         data_id_t void_id;
         data_id_init_void( &void_id );
@@ -183,7 +183,7 @@ static void layout_challenging_cases(void)
                                     &void_set,
                                     cr
                                   );
-        
+
         /* check result */
         /* TODO, manual chack for now */
 #ifdef PENCIL_DIAGRAM_MAKER_TEST_EXPORT_SAMPLES
@@ -194,7 +194,7 @@ static void layout_challenging_cases(void)
     test_data_setup_destroy( &ts_setup );
 }
 
-#ifndef NDEBUG                
+#ifndef NDEBUG
 static void layout_edge_cases(void)
 {
     test_data_setup_t ts_setup;
@@ -204,7 +204,7 @@ static void layout_edge_cases(void)
         /* setup */
         test_data_setup_get_variant_data( &ts_setup, &data_set );
         draw_background();
-        
+
         /* perform test: draw diagram */
         data_id_t void_id;
         data_id_init_void( &void_id );
@@ -220,7 +220,7 @@ static void layout_edge_cases(void)
                                     &void_set,
                                     cr
                                   );
-        
+
         /* check result */
         /* TODO, manual chack for now */
 #ifdef PENCIL_DIAGRAM_MAKER_TEST_EXPORT_SAMPLES
